import tkinter as tk
import tkinter.filedialog as fd
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt

def askinfilename(msg = None, types = [('', '*.*')]):
    """
            入力用ファイル名の設定
    """
    rt = tk.Tk()
    rt.withdraw()
    flnm = fd.askopenfilename(title = msg, filetypes = types)
    rt.destroy()
    return flnm

def askoutfilename(msg = None, types = [('', '*.*')], deftype = '.txt'):
    """
            出力用ファイル名の設定
    """
    rt = tk.Tk()
    rt.withdraw()
    flnm = fd.asksaveasfilename(title = msg, filetypes = types,
                                           defaultextension = deftype)
    rt.destroy()
    return flnm

finnm = askinfilename('入力データExcelファイル', types = [('Excel(*.xlsx)', '*.xlsx')])
foutnm = askoutfilename(msg = '画像保存ファイル', types = [('画像 (*.png)', '*.png')],
                       deftype = '.png')

xlsx_fl = pd.ExcelFile(finnm)
data_xlsx = pd.read_excel(xlsx_fl,  header = None)
data = data_xlsx.values

x_name = data[0,0]
y_name = data[0, 1]
x_values = data[1:, 0]
y_values = data[1:, 1]
print(x_name)
print(x_values)
print(y_name)
print(y_values)

#       日本語表記の設定
plt.rcParams['font.family'] = ['Yu Gothic', 'Noto Sans CJK JP', 'Hiragino Maru Gothic Pro']

plt.figure(figsize = (8, 5))                    #   画像のサイズ
plt.plot(x_values, y_values, 'b')               #   折れ線の描画
x_labels = ['{}'.format(v) for v in x_values]   #   横軸の値表示文字列
plt.xticks(x_values, x_labels, fontsize = 12)   #   横軸の目盛り
plt.xlabel(x_name, fontsize = 20)               #   横軸の変数名
plt.ylabel(y_name, fontsize = 20)               #   縦軸の変数名
plt.savefig(foutnm)                             #   画像の保存
plt.show()                                      #   画像の表示
